@@ -4,7 +4,7 @@ use warnings;
 
 use Time::HiRes qw/time/;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 use Test2::Plugin::OpenFixPerlIO;
 use IO::Handle;
@@ -20,16 +20,32 @@ sub PUSHED {
 
 sub WRITE {
     my ($self, $buffer, $handle) = @_;
-    my $time = time;
-    my $fileno = fileno($handle);
-    my $sync = "TEST2-SYNC-$fileno: $time\n";
+
+    if ($self->{DIED}) {
+        print $handle $buffer;
+        return length($buffer);
+    }
+
+    my $ok = eval {
+        my $time = time;
+        my $fileno = fileno($handle);
+        my $sync = "TEST2-SYNC-$fileno: $time\n";
+
+        my $mh = $MUX_FILES{$MUXED{$fileno}};
+        print $mh "START-$sync";
+        print $mh $buffer;
+        print $mh substr($buffer, -1, 1) eq "\n" ? "+STOP-$sync" : "\n-STOP-$sync";
+
+        1;
+    };
+    my $err = $@;
 
     print $handle $buffer;
 
-    my $mh = $MUX_FILES{$MUXED{$fileno}};
-    print $mh "START-$sync";
-    print $mh $buffer;
-    print $mh substr($buffer, -1, 1) eq "\n" ? "+STOP-$sync" : "\n-STOP-$sync";
+    unless ($ok) {
+        $self->{DIED}++;
+        die $err;
+    }
 
     return length($buffer);
 }
